===============================
nobeldb
===============================

.. image:: https://badge.fury.io/py/nobeldb.png
    :target: http://badge.fury.io/py/nobeldb

.. image:: https://travis-ci.org/ionrock/nobeldb.png?branch=master
        :target: https://travis-ci.org/ionrock/nobeldb

.. image:: https://pypip.in/d/nobeldb/badge.png
        :target: https://pypi.python.org/pypi/nobeldb


Nobel Prize Winner DB Shenanigans

* Free software: BSD license
* Documentation: https://nobeldb.readthedocs.org.

Features
--------

* TODO
